==> tomb_2.6+dfsg1.orig.tar.xz: Tomb-2.6/AUTHORS.md <==
Cryptsetup was originally written in 2004 by Jana Saout

LUKS extensions are written in 2006 by Clemens Fruhwirth

Tomb is written and maintained since 2007 by Denis Roio <jaromil@dyne.org>

Tomb includes code and advices by Anathema, Boyska, Hellekin O. Wolf,
Daniel Rodriguez, Parazyd, Alexandre Pujol, AitorATuin, Narrat and
Artur Malimonov.

The 'gtomb' GUI based on Zenity is written by Parazyd.

The Qt5 desktop tray GUI is written by Gianluca Montecchi.

Python Tomb wrappers are contributed by Reiven and Boyska.

Artwork is contributed by Jordi aka Mon Mort and Logan VanCuren.

Gettext internationalization and Spanish translation is contributed by
Daniel Rodriguez. French translation by Hellekin and Roy Lockhart,
Russian translation by fsLeg, German translation by Jerry Polfer,
Italian translation by Massimiliano Augello and Swedish translation by
PLJ / Kosovoper.

Testing, reviews and documentation contributed by Dreamer, Vlax,
Shining the Translucent, Mancausoft, Asbesto Molesto, Nignux, TheJH,
The Grugq, Reiven, GDrooid, Alphazo, Brian May, fsLeg, JoelMon,
Narrat, Jerry Polfer, Jim Turner, Maxime Arthaud, RobertMX,
mhogomchungu Mandeep Bhutani, Emil Lundberg, Joel Montes de Oca, Armin
Mesbah, Arusekk, Stephan Schindel, Asbjørn Apeland, Victor Calvert,
bjonnh, SargoDevel, AitorATuin, Alexis Danizan and...  the Linux
Action Show!

Tomb includes an implementation of the "Password-Based Key Derivation
Function v2" based on GCrypt and written by Anthony Thyssen, with
fixes contributed by AitorATuin.

Tomb developers can be contacted via GitHub issues on
https://www.github.com/dyne/Tomb or over IRC https://irc.dyne.org
channel **#dyne** (or directly over port 9999 with SSL)

==> tomb_2.7+dfsg2.orig.tar.xz: Tomb-2.7/AUTHORS.md <==
Cryptsetup was originally written in 2004 by Jana Saout

LUKS extensions are written in 2006 by Clemens Fruhwirth

Tomb is written and maintained since 2007 by Denis Roio <jaromil@dyne.org>

Tomb includes code and advices by Anathema, Boyska, Hellekin O. Wolf,
Daniel Rodriguez, Parazyd, Alexandre Pujol, AitorATuin, Narrat and
Artur Malimonov.

The 'gtomb' GUI based on Zenity is written by Parazyd.

The Qt5 desktop tray GUI is written by Gianluca Montecchi.

Python Tomb wrappers are contributed by Reiven and Boyska.

Artwork is contributed by Jordi aka Mon Mort and Logan VanCuren.

Gettext internationalization and Spanish translation is contributed by
Daniel Rodriguez. French translation by Hellekin and Roy Lockhart,
Russian translation by fsLeg, German translation by Jerry Polfer,
Italian translation by Massimiliano Augello and Swedish translation by
PLJ / Kosovoper.

Testing, reviews and documentation contributed by Dreamer, Vlax,
Shining the Translucent, Mancausoft, Asbesto Molesto, Nignux, TheJH,
The Grugq, Reiven, GDrooid, Alphazo, Brian May, fsLeg, JoelMon,
Narrat, Jerry Polfer, Jim Turner, Maxime Arthaud, RobertMX,
mhogomchungu Mandeep Bhutani, Emil Lundberg, Joel Montes de Oca, Armin
Mesbah, Arusekk, Stephan Schindel, Asbjørn Apeland, Victor Calvert,
bjonnh, SargoDevel, AitorATuin, Alexis Danizan, Sven Geuer and...
the Linux Action Show!

Tomb includes an implementation of the "Password-Based Key Derivation
Function v2" based on GCrypt and written by Anthony Thyssen, with
fixes contributed by AitorATuin.

Tomb developers can be contacted via GitHub issues on
https://www.github.com/dyne/Tomb or over IRC https://irc.dyne.org
channel **#dyne** (or directly over port 9999 with SSL)
